# This file was generated

import platform

import ctypes
from niscope import errors
from niscope import library
import threading


_instance = None
_instance_lock = threading.Lock()
_library_info = {'Linux': {'64bit': {'name': 'libscope.so', 'type': 'cdll'}},
                 'Windows': {'32bit': {'name': 'niscope_32.dll', 'type': 'windll'},
                             '64bit': {'name': 'niscope_64.dll', 'type': 'cdll'}}}


def _get_library_name():
    try:
        return _library_info[platform.system()][platform.architecture()[0]]['name']
    except KeyError:
        raise errors.UnsupportedConfigurationError


def _get_library_type():
    try:
        return _library_info[platform.system()][platform.architecture()[0]]['type']
    except KeyError:
        raise errors.UnsupportedConfigurationError


def get():
    '''get

    Returns the library.Library singleton for niscope.
    '''
    global _instance
    global _instance_lock

    with _instance_lock:
        if _instance is None:
            try:
                library_type = _get_library_type()
                if library_type == 'windll':
                    ctypes_library = ctypes.WinDLL(_get_library_name())
                else:
                    assert library_type == 'cdll'
                    ctypes_library = ctypes.CDLL(_get_library_name())
            except OSError:
                raise errors.DriverNotInstalledError()
            _instance = library.Library(ctypes_library)
        return _instance




import ctypes

from niscope import visatype


# This class is an internal implementation detail
# ctypes definition
# Name must match exactly what the name of the structure type is named in the C API.
class struct_niScope_wfmInfo(ctypes.Structure):  # noqa N801
    _pack_ = 8
    _fields_ = [
        ('absolute_initial_x', visatype.ViReal64),
        ('relative_initial_x', visatype.ViReal64),
        ('x_increment', visatype.ViReal64),
        ('actual_samples', visatype.ViInt32),
        ('offset', visatype.ViReal64),
        ('gain', visatype.ViReal64),
        ('reserved1', visatype.ViReal64),
        ('reserved2', visatype.ViReal64),
    ]

    def __init__(self, data=None, absolute_initial_x=0.0, relative_initial_x=0.0,
                 x_increment=0.0, actual_samples=0, offset=0.0, gain=0.0,
                 reserved1=0.0, reserved2=0.0):
        super(ctypes.Structure, self).__init__()
        if data is not None:
            self.absolute_initial_x = data.absolute_initial_x
            self.relative_initial_x = data.relative_initial_x
            self.x_increment = data.x_increment
            self.actual_samples = data.actual_samples
            self.offset = data.offset
            self.gain = data.gain
            self.reserved1 = data.reserved1
            self.reserved2 = data.reserved2
        else:
            self.absolute_initial_x = absolute_initial_x
            self.relative_initial_x = relative_initial_x
            self.x_increment = x_increment
            self.actual_samples = actual_samples
            self.offset = offset
            self.gain = gain
            self.reserved1 = reserved1
            self.reserved2 = reserved2


class WaveformInfo(object):
    def __init__(self, data=None, absolute_initial_x=0.0, relative_initial_x=0.0,
                 x_increment=0.0, actual_samples=0, offset=0.0, gain=0.0,
                 reserved1=0.0, reserved2=0.0):
        if data is not None:
            self.absolute_initial_x = data.absolute_initial_x
            self.relative_initial_x = data.relative_initial_x
            self.x_increment = data.x_increment
            self.actual_samples = data.actual_samples
            self.offset = data.offset
            self.gain = data.gain
            self.reserved1 = data.reserved1
            self.reserved2 = data.reserved2
        else:
            self.absolute_initial_x = absolute_initial_x
            self.relative_initial_x = relative_initial_x
            self.x_increment = x_increment
            self.actual_samples = actual_samples
            self.offset = offset
            self.gain = gain
            self.reserved1 = reserved1
            self.reserved2 = reserved2

    def __repr__(self):
        return '{0}(absolute_initial_x={1}, relative_initial_x={2}, x_increment={3}, actual_samples={4}, offset={5}, gain={6})'.format(
            self.__class__.__name__, self.absolute_initial_x, self.relative_initial_x, self.x_increment,
            self.actual_samples, self.offset, self.gain)

    def __str__(self):
        row_format_g = '{:<20}: {:,.6g}'
        row_format_d = '{:<20}: {:,}'
        string_representation = row_format_g.format('Absolute X0', self.absolute_initial_x) + '\n'
        string_representation += row_format_g.format('Relative X0', self.relative_initial_x) + '\n'
        string_representation += row_format_g.format('dt', self.x_increment) + '\n'
        string_representation += row_format_d.format('actual samples', self.actual_samples) + '\n'
        string_representation += row_format_g.format('offset', self.offset) + '\n'
        string_representation += row_format_g.format('gain', self.gain)
        return string_representation




#!/usr/bin/python
# This file was generated

from niscope.enums import *          # noqa: F403,F401,H303
from niscope.errors import Error     # noqa: F401
from niscope.errors import NiscopeWarning   # noqa: F401
from niscope.session import Session  # noqa: F401

from niscope.waveform_info import WaveformInfo  # noqa: F401

from niscope.waveform_info import struct_niScope_wfmInfo  # noqa: F401

